#include "FEM.h"

using namespace std;

//=========================================================
//=========================================================
//! main program
int main () {
    
  try{      

    clock_t begin, end;
    
    int n = 100;  
    SparseMatrix sparseMat( n , n );  
    Vector x(n), b(n);
    
    // fill matrix
    sparseMat(0, 0) = 2;
    sparseMat(0, 1) = -1.;
       
    for( int i = 1; i < n-1; i++ ){
       sparseMat(i, i-1) = -1.;
       sparseMat(i, i)   =  2.;
       sparseMat(i, i+1) = -1.;
    }
    
    sparseMat(n-1, n-1) = 2;
    sparseMat(n-1, n-2) = -1.;
    
    // fill vector
    b.setAll( 1./n );
   
    //sparseMat.print();
    
    // solve with CG
    CGSolver cgSolver( 1e-8, 10000 ); 
    begin = clock();     
    cgSolver.solve( sparseMat, b, x );    
    end = clock();  
    cerr << "Time for CG = " << double(end - begin) / CLOCKS_PER_SEC << endl;
    
    // write console output
    x.print();   
  
  }
  catch ( const char* exc ){
    cerr << "Exception caught: " << exc << endl;
  }

  return 0;
}